====================
Development Projects
====================

There following different types of development embeddings are available:

- The :doc:`Development Collection <collection>`

In the next sections we will show you how you can enable and configure those embeddings.

We will also take a look at the :doc:`representation of a single development <details>`.


.. toctree::
   :hidden:
   :maxdepth: 2

   collection
   details
